@@ -66,11 +66,11 @@
 #undef R__HAS_DEFAULT_ZSTD  /**/
 #undef R__HAS_CLOUDFLARE_ZLIB /**/
 
-#define R__HAS_TMVACPU /**/
+#undef R__HAS_TMVACPU /**/
 #undef R__HAS_TMVAGPU /**/
 #undef R__HAS_CUDNN /**/
 #undef R__HAS_PYMVA /**/
-#define R__HAS_RMVA /**/
+#undef R__HAS_RMVA /**/
 
 #undef R__HAS_URING /**/
 
