@@ -573,10 +573,10 @@ struct Limits {
 ////////////////////////////////////////////////////////////////////////////////
 // Trig and other functions
 
-#include <float.h>
-#include <math.h>
+#include <cfloat>
+#include <cmath>
 
-#if defined(R__WIN32) && !defined(__CINT__)
+#if defined(R__WIN32)
 #   ifndef finite
 #      define finite _finite
 #   endif
